@@ -4,12 +4,15 @@
 # Copyright 2010 K. Richard Pixley.
 # See LICENSE for details.
 #
-# Time-stamp: <23-Feb-2010 13:29:05 PST by rich@noir.com>
+# Time-stamp: <25-Feb-2010 07:37:37 PST by rich@noir.com>
 
 """
-A package which offers a simple, covering interface for a variety of other serializers.
+A package which offers a simple, covering interface for a variety of
+other serializers.
 """
 
+from __future__ import unicode_literals
+
 __docformat__ = 'epytext'
 
 __all__ = []
@@ -22,10 +25,18 @@ class MetaSerializer(object):
     Base class for MetaSerializer objects.
 
     @ivar name:
-    @type name: C{str}
+    @type name: C{unicode}
+
+    @ivar magic:
+    @type magic: a C{bytes} of length 1.  This is used to identify
+    upcoming serializations.  Individual serializer magic assignments
+    must be unique and cannot change without destroying compatibility
+    with existing serializations.  For example, any outstanding log
+    files.
     """
 
     name = 'unknown'
+    magic = b' '
 
     def dump(self, o, f):
         """
@@ -51,26 +62,41 @@ class MetaSerializer(object):
         """
         raise NotImplementedError
 
-    def dumps(self, o):
+    def dumpb(self, o):
         """
-        Serialize an C{object} into a C{str}.
+        Serialize an C{object} into a C{bytes}.
 
         @param object:
         @type object: C{object}
 
         @return:
-        @rtype: C{str}
+        @rtype: C{bytes}
         """
         raise NotImplementedError
 
-    def loads(self, s):
+    def loadb(self, b):
         """
-        Unserialize an C{object} from a C{str}.
+        Unserialize an C{object} from a C{bytes}.
 
-        @param string:
-        @type string: C{str}
+        @param bytes:
+        @type bytes: C{bytes}
 
         @return:
         @rtype: C{object}
         """
         raise NotImplementedError
+
+
+_registry = {}
+
+def _register(cls):
+    assert cls.magic not in _registry
+
+    _registry[cls.magic] = cls
+
+def SerializerFromMagic(character):
+    assert isinstance(character, bytes)
+    assert len(character) == 1
+    assert character != ' '
+
+    return _registry[character]()
