@@ -4,7 +4,7 @@
 # Copyright 2010 K. Richard Pixley.
 # See LICENSE for details.
 #
-# Time-stamp: <23-Feb-2010 17:46:17 PST by rich@noir.com>
+# Time-stamp: <25-Feb-2010 07:37:37 PST by rich@noir.com>
 
 """
 This module subclasses the MetaSerializer object into a json
@@ -15,9 +15,11 @@ simplejson).
 noop.
 """
 
+from __future__ import unicode_literals
+
 __docformat__ = 'epytext'
 
-from metaserializer import MetaSerializer
+from metaserializer import MetaSerializer, _register
 
 import json
 
@@ -26,9 +28,13 @@ class JSON(MetaSerializer):
     This serializer is based on the standard library json module, (aka, simplejson).
     """
     name = 'json'
+    magic = b'd'
 
-    def dumps(self, object):
-        return json.dumps(object, sort_keys=True, indent=4)
+    def dumpb(self, object):
+        return bytes(json.dumps(object, sort_keys=True, indent=4))
 
-    def loads(self, string):
-        return json.loads(string)
+    def loadb(self, b):
+        assert isinstance(b, bytes)
+        return json.loads(b)
+
+_register(JSON)
